summaryrefslogtreecommitdiffstats
path: root/parts/snippet/snippet_widget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/snippet/snippet_widget.cpp')
-rw-r--r--parts/snippet/snippet_widget.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/parts/snippet/snippet_widget.cpp b/parts/snippet/snippet_widget.cpp
index 447193f4..dd057a29 100644
--- a/parts/snippet/snippet_widget.cpp
+++ b/parts/snippet/snippet_widget.cpp
@@ -47,13 +47,13 @@
#include "snippet_widget.h"
SnippetWidget::SnippetWidget(SnippetPart *part)
- : KListView(0, "snippet widget"), TQToolTip( viewport() ),
+ : TDEListView(0, "snippet widget"), TQToolTip( viewport() ),
m_part( part )
{
// init the TQPtrList
_list.setAutoDelete(TRUE);
// init the KListView
setSorting( -1 );
addColumn( "" );
setFullWidth(true);
@@ -213,7 +213,7 @@ void SnippetWidget::slotEdit()
dlg.cbGroup->setCurrentText(SnippetItem::findGroupById(pSnippet->getParent(), _list)->getName());
if (dlg.exec() == TQDialog::Accepted) {
//update the KListView and the SnippetItem
item->setText( 0, dlg.snippetName->text() );
pSnippet->setName( dlg.snippetName->text() );
pSnippet->setText( dlg.snippetText->text() );
@@ -256,7 +256,7 @@ void SnippetWidget::slotEditGroup()
dlg.textLabelGroup->setText(i18n("Language:"));
if (dlg.exec() == TQDialog::Accepted) {
//update the KListView and the SnippetGroup
item->setText( 0, dlg.snippetName->text() );
pGroup->setName( dlg.snippetName->text() );
pGroup->setLanguage(dlg.cbGroup->currentText());
@@ -545,7 +545,7 @@ void SnippetWidget::maybeTip( const TQPoint & p )
*/
void SnippetWidget::showPopupMenu( TQListViewItem * item, const TQPoint & p, int )
{
- KPopupMenu popup;
+ TDEPopupMenu popup;
SnippetItem * selectedItem = static_cast<SnippetItem *>(item);
if ( item ) {
@@ -882,7 +882,7 @@ TQString SnippetWidget::showSingleVarDialog(TQString var, TQMap<TQString, TQStri
// fn SnippetWidget::acceptDrag (TQDropEvent *event) const
/*!
- Reimplementation from KListView.
+ Reimplementation from TDEListView.
Check here if the data the user is about to drop fits our restrictions.
We only accept dropps of plaintext, because from the dropped text
we will create a snippet.
@@ -47,13 +47,13 @@
// init the TQPtrList
_list.setAutoDelete(TRUE);
- // init the KListView
+ // init the TDEListView
setSorting( -1 );
addColumn( "" );
@@ -213,7 +213,7 @@ void SnippetWidget::slotEdit()
dlg.cbGroup->setCurrentText(SnippetItem::findGroupById(pSnippet->getParent(), _list)->getName());
if (dlg.exec() == TQDialog::Accepted) {
- //update the KListView and the SnippetItem
+ //update the TDEListView and the SnippetItem
item->setText( 0, dlg.snippetName->text() );
pSnippet->setName( dlg.snippetName->text() );
@@ -256,7 +256,7 @@ void SnippetWidget::slotEditGroup()
dlg.textLabelGroup->setText(i18n("Language:"));
if (dlg.exec() == TQDialog::Accepted) {
- //update the KListView and the SnippetGroup
+ //update the TDEListView and the SnippetGroup
item->setText( 0, dlg.snippetName->text() );
pGroup->setName( dlg.snippetName->text() );